@@ -8,7 +8,7 @@ from typing import Callable, Optional, Union
 from omotes_sdk.internal.common.broker_interface import (
     BrokerInterface,
     AMQPQueueType,
-    QueueMessageTTLArguments,
+    QueueTTLArguments,
 )
 from omotes_sdk.config import RabbitMQConfig
 from omotes_sdk_protocol.job_pb2 import (
@@ -108,8 +108,8 @@ class OmotesInterface:
     """How long the SDK should wait for the first reply when requesting the current workflow
     definitions from the orchestrator."""
 
-    JOB_RESULT_MESSAGE_TTL: timedelta = timedelta(hours=48)
-    """Default value of job result message TTL."""
+    JOB_QUEUES_TTL: timedelta = timedelta(hours=48)
+    """Default value of job result, progress, and status queue TTL."""
 
     def __init__(
         self,
@@ -181,7 +181,7 @@ class OmotesInterface:
         callback_on_progress_update: Optional[Callable[[Job, JobProgressUpdate], None]],
         callback_on_status_update: Optional[Callable[[Job, JobStatusUpdate], None]],
         auto_disconnect_on_result: bool,
-        auto_dead_letter_after_ttl: Optional[timedelta] = JOB_RESULT_MESSAGE_TTL,
+        auto_cleanup_after_ttl: Optional[timedelta] = JOB_QUEUES_TTL,
         reconnect: bool = True,
     ) -> None:
         """(Re)connect to the running job.
@@ -196,12 +196,11 @@ class OmotesInterface:
         :param auto_disconnect_on_result: Remove/disconnect from all queues pertaining to this job
             once the result is received and handled without exceptions through
             `callback_on_finished`.
-        :param auto_dead_letter_after_ttl: When erroneous situations occur (e.g. client is offline),
-            the job result message (if available) will be dead lettered after the given TTL,
-            and all queues of this job will be removed subsequently. Default to 48 hours if unset.
-            Set to `None` to turn off auto dead letter and clean up, but be aware this may lead to
-            messages and queues to be stored in RabbitMQ indefinitely
-            (which uses up memory & disk space).
+        :param auto_cleanup_after_ttl: When erroneous situations occur (e.g. client is offline),
+            all queues pertaining to this job will be removed after the given TTL.
+            Default to 48 hours if unset. Set to `None` to turn off auto clean up,
+            but be aware this may lead to leftover messages and queues to be stored
+            in RabbitMQ indefinitely (which uses up memory & disk space).
         :param reconnect: When True, first check the job queues status and raise an error if not
             exist. Default to True.
         """
@@ -240,32 +239,21 @@ class OmotesInterface:
             logger.info("Connecting to update for job %s and expect manual disconnect", job.id)
             auto_disconnect_handler = None
 
-        # TODO: handle reconnection after the message is dead lettered but queue still exists.
-
-        if auto_dead_letter_after_ttl is not None:
-            message_ttl = auto_dead_letter_after_ttl
-            queue_ttl = auto_dead_letter_after_ttl * 2
+        if auto_cleanup_after_ttl is not None:
+            queue_ttl = auto_cleanup_after_ttl
             logger.info(
-                "Auto dead letter and cleanup on error after TTL is set. "
-                + "The leftover job result message will be dead lettered after %s, "
+                "Auto job queues clean up on error after TTL is set. "
+                + "The leftover job messages will be dropped, "
                 + "and leftover job queues will be discarded after %s.",
-                message_ttl,
                 queue_ttl,
             )
-            job_result_queue_message_ttl = QueueMessageTTLArguments(
-                queue_ttl=queue_ttl,
-                message_ttl=message_ttl,
-                dead_letter_routing_key=OmotesQueueNames.job_result_dead_letter_queue_name(),
-                dead_letter_exchange=OmotesQueueNames.omotes_exchange_name(),
-            )
-            job_progress_status_queue_ttl = QueueMessageTTLArguments(queue_ttl=queue_ttl)
+            job_queue_ttl = QueueTTLArguments(queue_ttl=queue_ttl)
         else:
             logger.info(
-                "Auto dead letter and cleanup on error after TTL is not set. "
+                "Auto job queues clean up on error after TTL is not set. "
                 + "Manual cleanup on leftover job queues and messages might be required."
             )
-            job_result_queue_message_ttl = None
-            job_progress_status_queue_ttl = None
+            job_queue_ttl = None
 
         callback_handler = JobSubmissionCallbackHandler(
             job,
@@ -275,21 +263,13 @@ class OmotesInterface:
             auto_disconnect_handler,
         )
 
-        self.broker_if.declare_queue_and_add_subscription(
-            queue_name=job_results_queue_name,
-            callback_on_message=callback_handler.callback_on_finished_wrapped,
-            queue_type=AMQPQueueType.DURABLE,
-            exchange_name=OmotesQueueNames.omotes_exchange_name(),
-            delete_after_messages=1,
-            queue_message_ttl=job_result_queue_message_ttl,
-        )
         if callback_on_progress_update:
             self.broker_if.declare_queue_and_add_subscription(
                 queue_name=job_progress_queue_name,
                 callback_on_message=callback_handler.callback_on_progress_update_wrapped,
                 queue_type=AMQPQueueType.DURABLE,
                 exchange_name=OmotesQueueNames.omotes_exchange_name(),
-                queue_message_ttl=job_progress_status_queue_ttl,
+                queue_ttl=job_queue_ttl,
             )
         if callback_on_status_update:
             self.broker_if.declare_queue_and_add_subscription(
@@ -297,8 +277,19 @@ class OmotesInterface:
                 callback_on_message=callback_handler.callback_on_status_update_wrapped,
                 queue_type=AMQPQueueType.DURABLE,
                 exchange_name=OmotesQueueNames.omotes_exchange_name(),
-                queue_message_ttl=job_progress_status_queue_ttl,
+                queue_ttl=job_queue_ttl,
             )
+        # Declares the job result queue last to ensure the job progress
+        # and status queues are already declared and exist. This order allows
+        # them to be properly removed by _autodelete_progres_status_queues_on_result()
+        self.broker_if.declare_queue_and_add_subscription(
+            queue_name=job_results_queue_name,
+            callback_on_message=callback_handler.callback_on_finished_wrapped,
+            queue_type=AMQPQueueType.DURABLE,
+            exchange_name=OmotesQueueNames.omotes_exchange_name(),
+            delete_after_messages=1,
+            queue_ttl=job_queue_ttl,
+        )
 
     def submit_job(
         self,
@@ -311,7 +302,7 @@ class OmotesInterface:
         callback_on_status_update: Optional[Callable[[Job, JobStatusUpdate], None]],
         auto_disconnect_on_result: bool,
         job_reference: Optional[str] = None,
-        auto_dead_letter_after_ttl: Optional[timedelta] = JOB_RESULT_MESSAGE_TTL,
+        auto_cleanup_after_ttl: Optional[timedelta] = JOB_QUEUES_TTL,
     ) -> Job:
         """Submit a new job and connect to progress and status updates and the job result.
 
@@ -331,12 +322,11 @@ class OmotesInterface:
             `callback_on_finished`.
         :param job_reference: An optional reference to the submitted job which is used in the
             name of the output ESDL as well as in internal logging of OMOTES.
-        :param auto_dead_letter_after_ttl: When erroneous situations occur (e.g. client is offline),
-            the job result message (if available) will be dead lettered after the given TTL,
-            and all queues of this job will be removed subsequently. Default to 48 hours if unset.
-            Set to `None` to turn off auto dead letter and clean up, but be aware this may lead to
-            messages and queues to be stored in RabbitMQ indefinitely
-            (which uses up memory & disk space).
+        :param auto_cleanup_after_ttl: When erroneous situations occur (e.g. client is offline),
+            all queues pertaining to this job will be removed after the given TTL.
+            Default to 48 hours if unset. Set to `None` to turn off auto clean up,
+            but be aware this may lead to leftover messages and queues to be stored
+            in RabbitMQ indefinitely (which uses up memory & disk space).
         :raises UnknownWorkflowException: If `workflow_type` is unknown as a possible workflow in
             this interface.
         :return: The job handle which is created. This object needs to be saved persistently by the
@@ -356,7 +346,7 @@ class OmotesInterface:
             callback_on_progress_update,
             callback_on_status_update,
             auto_disconnect_on_result,
-            auto_dead_letter_after_ttl,
+            auto_cleanup_after_ttl,
             reconnect,
         )
 
