@@ -1,5 +1,4 @@
-from omotes_sdk.job import Job
-from omotes_sdk.workflow_type import WorkflowType
+import uuid
 
 
 class OmotesQueueNames:
@@ -14,40 +13,39 @@ class OmotesQueueNames:
         return "omotes_exchange"
 
     @staticmethod
-    def job_submission_queue_name(workflow_type: WorkflowType) -> str:
-        """Generate the job submission queue name given the workflow type.
+    def job_submission_queue_name() -> str:
+        """Generate the job submission queue name.
 
-        :param workflow_type: Workflow type.
         :return: The queue name.
         """
-        return f"job_submissions.{workflow_type.workflow_type_name}"
+        return "job_submissions"
 
     @staticmethod
-    def job_results_queue_name(job: Job) -> str:
-        """Generate the job results queue name given the job.
+    def job_results_queue_name(job_uuid: uuid.UUID) -> str:
+        """Generate the job results queue name given the job id.
 
-        :param job: The job.
+        :param job_uuid: The identifier of the job.
         :return: The queue name.
         """
-        return f"jobs.{job.id}.result"
+        return f"jobs.{job_uuid}.result"
 
     @staticmethod
-    def job_progress_queue_name(job: Job) -> str:
-        """Generate the job progress update queue name given the job.
+    def job_progress_queue_name(job_uuid: uuid.UUID) -> str:
+        """Generate the job progress update queue name given the job id.
 
-        :param job: The job.
+        :param job_uuid: The identifier of the job.
         :return: The queue name.
         """
-        return f"jobs.{job.id}.progress"
+        return f"jobs.{job_uuid}.progress"
 
     @staticmethod
-    def job_status_queue_name(job: Job) -> str:
-        """Generate the job status update queue name given the job.
+    def job_status_queue_name(job_uuid: uuid.UUID) -> str:
+        """Generate the job status update queue name given the job id.
 
-        :param job: The job.
+        :param job_uuid: The identifier of the job.
         :return: The queue name.
         """
-        return f"jobs.{job.id}.status"
+        return f"jobs.{job_uuid}.status"
 
     @staticmethod
     def job_cancel_queue_name() -> str:
